@@ -1,9 +1,11 @@
 from bluer_ugv.help.swallow.dataset import help_functions as help_dataset
+from bluer_ugv.help.swallow.debug import help_debug
 from bluer_ugv.help.swallow.env import help_functions as help_env
 from bluer_ugv.help.swallow.select_target import help_select_target
 
 help_functions = {
     "dataset": help_dataset,
+    "debug": help_debug,
     "env": help_env,
     "select_target": help_select_target,
 }
