@@ -3,9 +3,9 @@ from bluer_ugv.parts.part_db import PartDB
 
 db_of_parts: PartDB = PartDB()
 
-db_of_parts["330-ohm"] = Part(
+db_of_parts["resistor"] = Part(
     info=[
-        "Resistor, 330-470 Ω, 1/4 watt, 5% tolerance",
+        "Resistor, 1/4 watt, 5% tolerance",
     ],
     images=["resistor.png"],
 )
@@ -36,7 +36,9 @@ db_of_parts["BTS7960"] = Part(
 
 db_of_parts["dc-motor-12-VDC-45W"] = Part(
     info=[
-        "12 VDC motor, 20-45 W, 9000 RPM",
+        "12 VDC motor, 20-45 W",
+        "type 1: 9,000 RPM, output ~60 RPM",
+        "type 2: 10,000 RPM, output 72 RPM",
         "https://parsbike.com/product/%D9%85%D9%88%D8%AA%D9%88%D8%B1-%DA%AF%DB%8C%D8%B1%D8%A8%DA%A9%D8%B3-%D9%85%D8%A7%D8%B4%DB%8C%D9%86-%D8%B4%D8%A7%D8%B1%DA%98%DB%8C-%D9%88-%D9%85%D9%88%D8%AA%D9%88%D8%B1-%D8%B4%D8%A7%D8%B1%DA%98%DB%8C/",
     ],
     images=[
@@ -294,6 +296,27 @@ db_of_parts["wheel"] = Part(
     ],
 )
 
+db_of_parts["ultrasonic-sensor"] = Part(
+    info=[
+        "HC-SR04",
+        "[datasheet](https://cdn.sparkfun.com/datasheets/Sensors/Proximity/HCSR04.pdf)",
+        "1m ~= 6ms",
+        "fov = 15 - 30 deg",
+    ],
+    images=[
+        "HC-SR04.jpg",
+    ],
+)
+
+db_of_parts["connector"] = Part(
+    info=[
+        "auto power connectors",
+    ],
+    images=[
+        "connector.jpg",
+    ],
+)
+
 db_of_parts["template"] = Part(
     info=[
         "template",
