@@ -1,6 +1,6 @@
 from bluer_ugv.swallow.session.classical.leds import ClassicalLeds
 from bluer_ugv.swallow.session.classical.motor.generic import GenericMotor
-from bluer_ugv.swallow.session.classical.setpoint import ClassicalSetPoint
+from bluer_ugv.swallow.session.classical.setpoint.classes import ClassicalSetPoint
 
 
 class ClassicalRearMotors(GenericMotor):
