@@ -1,19 +1,24 @@
 from RPi import GPIO  # type: ignore
 
-from bluer_sbc.env import BLUER_SBC_ENV
+from bluer_sbc.env import BLUER_SBC_ENV, BLUER_SBC_SWALLOW_HAS_STEERING
 
 from bluer_ugv.swallow.session.classical.camera import (
     ClassicalCamera,
     ClassicalNavigationCamera,
     ClassicalTrackingCamera,
+    ClassicalYoloCamera,
 )
 from bluer_ugv.swallow.session.classical.push_button import ClassicalPushButton
 from bluer_ugv.swallow.session.classical.keyboard import ClassicalKeyboard
 from bluer_ugv.swallow.session.classical.leds import ClassicalLeds
 from bluer_ugv.swallow.session.classical.mousepad import ClassicalMousePad
-from bluer_ugv.swallow.session.classical.motor.rear import ClassicalRearMotors
-from bluer_ugv.swallow.session.classical.motor.steering import ClassicalSteeringMotor
-from bluer_ugv.swallow.session.classical.setpoint import ClassicalSetPoint
+from bluer_ugv.swallow.session.classical.motor import (
+    ClassicalLeftMotor,
+    ClassicalRightMotor,
+    ClassicalRearMotors,
+    ClassicalSteeringMotor,
+)
+from bluer_ugv.swallow.session.classical.setpoint.classes import ClassicalSetPoint
 from bluer_ugv.env import BLUER_UGV_MOUSEPAD_ENABLED
 from bluer_ugv.logger import logger
 
@@ -45,23 +50,41 @@ class ClassicalSession:
             leds=self.leds,
         )
 
-        self.steering = ClassicalSteeringMotor(
+        self.has_steering = BLUER_SBC_SWALLOW_HAS_STEERING == 1
+        logger.info("has_steering: {}".format(self.has_steering))
+
+        self.motor1 = (
+            ClassicalSteeringMotor if self.has_steering else ClassicalRightMotor
+        )(
             setpoint=self.setpoint,
             leds=self.leds,
         )
 
-        self.rear = ClassicalRearMotors(
+        self.motor2 = (
+            ClassicalRearMotors if self.has_steering else ClassicalLeftMotor
+        )(
             setpoint=self.setpoint,
             leds=self.leds,
         )
 
+        logger.info(
+            "wheel arrangement: {} + {}".format(
+                self.motor1.role,
+                self.motor2.role,
+            )
+        )
+
         camera_class = (
-            ClassicalTrackingCamera
-            if BLUER_SBC_ENV == "tracking"
+            ClassicalYoloCamera
+            if BLUER_SBC_ENV == "yolo"
             else (
-                ClassicalNavigationCamera
-                if BLUER_SBC_ENV == "navigation"
-                else ClassicalCamera
+                ClassicalTrackingCamera
+                if BLUER_SBC_ENV == "tracking"
+                else (
+                    ClassicalNavigationCamera
+                    if BLUER_SBC_ENV == "navigation"
+                    else ClassicalCamera
+                )
             )
         )
         logger.info(f"camera: {camera_class.__name__}")
@@ -81,8 +104,8 @@ class ClassicalSession:
 
     def cleanup(self):
         for thing in [
-            self.rear,
-            self.steering,
+            self.motor1,
+            self.motor2,
             self.camera,
         ]:
             thing.cleanup()
@@ -103,8 +126,8 @@ class ClassicalSession:
             for thing in [
                 self.push_button,
                 self.leds,
-                self.steering,
-                self.rear,
+                self.motor1,
+                self.motor2,
                 self.camera,
             ]
         )
@@ -117,8 +140,8 @@ class ClassicalSession:
                 self.push_button,
                 self.camera,
                 self.setpoint,
-                self.steering,
-                self.rear,
+                self.motor1,
+                self.motor2,
                 self.leds,
             ]
         )
